==> tidy3d-2.8.0rc1.tar.gz: tidy3d-2.8.0rc1/tidy3d/plugins/autograd/__init__.py <==
from .differential_operators import grad, value_and_grad
from .functions import (
    add_at,
    convolve,
    grey_closing,
    grey_dilation,
    grey_erosion,
    grey_opening,
    interpn,
    least_squares,
    morphological_gradient,
    morphological_gradient_external,
    morphological_gradient_internal,
    pad,
    rescale,
    smooth_max,
    smooth_min,
    threshold,
    trapz,
)
from .invdes import (
    CircularFilter,
    ConicFilter,
    ErosionDilationPenalty,
    FilterAndProject,
    grey_indicator,
    make_circular_filter,
    make_conic_filter,
    make_curvature_penalty,
    make_erosion_dilation_penalty,
    make_filter,
    make_filter_and_project,
    ramp_projection,
    tanh_projection,
)
from .primitives import gaussian_filter
from .utilities import chain, get_kernel_size_px, make_kernel, scalar_objective

__all__ = [
    "CircularFilter",
    "ConicFilter",
    "ErosionDilationPenalty",
    "FilterAndProject",
    "make_filter",
    "make_conic_filter",
    "make_circular_filter",
    "grey_indicator",
    "convolve",
    "pad",
    "ramp_projection",
    "tanh_projection",
    "make_erosion_dilation_penalty",
    "make_curvature_penalty",
    "make_filter_and_project",
    "gaussian_filter",
    "make_kernel",
    "get_kernel_size_px",
    "chain",
    "grey_closing",
    "grey_dilation",
    "grey_erosion",
    "grey_opening",
    "morphological_gradient",
    "morphological_gradient_external",
    "morphological_gradient_internal",
    "rescale",
    "threshold",
    "value_and_grad",
    "smooth_min",
    "smooth_max",
    "add_at",
    "interpn",
    "least_squares",
    "grad",
    "scalar_objective",
    "trapz",
]

==> tidy3d-2.10.0rc1.tar.gz: tidy3d-2.10.0rc1/tidy3d/plugins/autograd/__init__.py <==
from __future__ import annotations

from .differential_operators import grad, value_and_grad
from .functions import (
    add_at,
    convolve,
    grey_closing,
    grey_dilation,
    grey_erosion,
    grey_opening,
    interpn,
    least_squares,
    morphological_gradient,
    morphological_gradient_external,
    morphological_gradient_internal,
    pad,
    rescale,
    smooth_max,
    smooth_min,
    threshold,
    trapz,
)
from .invdes import (
    CircularFilter,
    ConicFilter,
    ErosionDilationPenalty,
    FilterAndProject,
    grey_indicator,
    initialize_params_from_simulation,
    make_circular_filter,
    make_conic_filter,
    make_curvature_penalty,
    make_erosion_dilation_penalty,
    make_filter,
    make_filter_and_project,
    ramp_projection,
    tanh_projection,
)
from .primitives import gaussian_filter, interpolate_spline
from .utilities import chain, get_kernel_size_px, make_kernel, scalar_objective

__all__ = [
    "CircularFilter",
    "ConicFilter",
    "ErosionDilationPenalty",
    "FilterAndProject",
    "add_at",
    "chain",
    "convolve",
    "gaussian_filter",
    "get_kernel_size_px",
    "grad",
    "grey_closing",
    "grey_dilation",
    "grey_erosion",
    "grey_indicator",
    "grey_opening",
    "initialize_params_from_simulation",
    "interpn",
    "interpolate_spline",
    "least_squares",
    "make_circular_filter",
    "make_conic_filter",
    "make_curvature_penalty",
    "make_erosion_dilation_penalty",
    "make_filter",
    "make_filter_and_project",
    "make_kernel",
    "morphological_gradient",
    "morphological_gradient_external",
    "morphological_gradient_internal",
    "pad",
    "ramp_projection",
    "rescale",
    "scalar_objective",
    "smooth_max",
    "smooth_min",
    "tanh_projection",
    "threshold",
    "trapz",
    "value_and_grad",
]
